pub enum VaultError {
Show 55 variants
InstructionUnpackError,
NotRentExempt,
AlreadyInitialized,
Uninitialized,
IncorrectOwner,
NumericalOverflowError,
TokenAccountContainsNoTokens,
TokenAccountAmountLessThanAmountSpecified,
VaultAccountIsNotEmpty,
VaultAccountIsNotOwnedByProgram,
SafetyDepositAddressInvalid,
TokenTransferFailed,
TokenMintToFailed,
TokenBurnFailed,
VaultMintNotEmpty,
VaultAuthorityNotProgram,
TreasuryNotEmpty,
TreasuryOwnerNotProgram,
VaultShouldBeInactive,
VaultShouldBeActive,
VaultShouldBeCombined,
VaultTreasuryMintDoesNotMatchVaultMint,
RedeemTreasuryCantShareSameMintAsFraction,
InvalidAuthority,
RedeemTreasuryMintMustMatchLookupMint,
PaymentMintShouldMatchPricingMint,
ShareMintShouldMatchFractionalMint,
VaultMintNeedsToMatchVault,
RedeemTreasuryNeedsToMatchVault,
FractionTreasuryNeedsToMatchVault,
NotAllowedToCombine,
CannotAffordToCombineThisVault,
NoShares,
OutstandingShareAccountNeedsToMatchFractionalMint,
DestinationAccountNeedsToMatchRedeemMint,
FractionSupplyEmpty,
TokenProgramProvidedDoesNotMatchVault,
AuthorityIsNotSigner,
AuthorityDoesNotMatch,
SafetyDepositBoxVaultMismatch,
StoreDoesNotMatchSafetyDepositBox,
StoreEmpty,
DestinationAccountNeedsToMatchTokenMint,
DestinationAccountNeedsToMatchFractionMint,
SourceAccountNeedsToMatchFractionMint,
VaultDoesNotAllowNewShareMinting,
NotEnoughShares,
ExternalPriceAccountMustBeSigner,
RedeemTreasuryMintShouldMatchPricingMint,
StoreLessThanAmount,
InvalidTokenProgram,
DataTypeMismatch,
DelegateShouldBeNone,
CloseAuthorityShouldBeNone,
DerivedKeyInvalid,
}Expand description
Errors that may be returned by the Vault program.
Variants
InstructionUnpackError
Invalid instruction data passed in.
NotRentExempt
Lamport balance below rent-exempt threshold.
AlreadyInitialized
Already initialized
Uninitialized
Uninitialized
IncorrectOwner
Account does not have correct owner
NumericalOverflowError
NumericalOverflowError
TokenAccountContainsNoTokens
Provided token account contains no tokens
TokenAccountAmountLessThanAmountSpecified
Provided token account cannot provide amount specified
VaultAccountIsNotEmpty
Provided vault account contains is not empty
VaultAccountIsNotOwnedByProgram
Provided vault account is not owned by program
SafetyDepositAddressInvalid
The provided safety deposit account address does not match the expected program derived address
TokenTransferFailed
Token transfer failed
TokenMintToFailed
Token mint to failed
TokenBurnFailed
Token burn failed
VaultMintNotEmpty
Vault mint not empty on int
VaultAuthorityNotProgram
Vault mint’s authority not set to program
TreasuryNotEmpty
Vault treasury not empty on init
TreasuryOwnerNotProgram
Vault treasury’s owner not set to program
VaultShouldBeInactive
Vault should be inactive
VaultShouldBeActive
Vault should be active
VaultShouldBeCombined
Vault should be combined
VaultTreasuryMintDoesNotMatchVaultMint
Vault treasury needs to match fraction mint
Redeem Treasury cannot be same mint as fraction
InvalidAuthority
Invalid program authority provided
RedeemTreasuryMintMustMatchLookupMint
Redeem treasury mint must match lookup mint
PaymentMintShouldMatchPricingMint
You must pay with the same mint as the external pricing oracle
Your share account should match the mint of the fractional mint
VaultMintNeedsToMatchVault
Vault mint provided does not match that on the token vault
RedeemTreasuryNeedsToMatchVault
Redeem treasury provided does not match that on the token vault
FractionTreasuryNeedsToMatchVault
Fraction treasury provided does not match that on the token vault
NotAllowedToCombine
Not allowed to combine at this time
CannotAffordToCombineThisVault
You cannot afford to combine this pool
You have no shares to redeem
Your outstanding share account is the incorrect mint
DestinationAccountNeedsToMatchRedeemMint
Your destination account is the incorrect mint
FractionSupplyEmpty
Fractional mint is empty
TokenProgramProvidedDoesNotMatchVault
Token Program Provided Needs To Match Vault
AuthorityIsNotSigner
Authority of vault needs to be signer for this action
AuthorityDoesNotMatch
Authority of vault does not match authority provided
SafetyDepositBoxVaultMismatch
This safety deposit box does not belong to this vault!
StoreDoesNotMatchSafetyDepositBox
The store provided does not match the store key on the safety deposit box!
StoreEmpty
This safety deposit box is empty!
DestinationAccountNeedsToMatchTokenMint
The destination account to receive your token needs to be the same mint as the token’s mint
DestinationAccountNeedsToMatchFractionMint
The destination account to receive your shares needs to be the same mint as the vault’s fraction mint
SourceAccountNeedsToMatchFractionMint
The source account to send your shares from needs to be the same mint as the vault’s fraction mint
This vault does not allow the minting of new shares!
There are not enough shares
ExternalPriceAccountMustBeSigner
External price account must be signer
RedeemTreasuryMintShouldMatchPricingMint
Very bad, someone changed external account’s price mint after vault creation!
StoreLessThanAmount
Store has less than amount desired
InvalidTokenProgram
Invalid token program
DataTypeMismatch
Data type mismatch
DelegateShouldBeNone
Accept payment delegate should be none
CloseAuthorityShouldBeNone
Accept payment close authority should be none
DerivedKeyInvalid
Derived key invalid